pub struct SchemaOperator { /* private fields */ }Expand description
Explicit operator-only setup and upgrade workflows for one owned schema.
Implementations
Sourceimpl SchemaOperator
impl SchemaOperator
Sourcepub async fn connect(
database_url: &str,
plan: SchemaPlan,
) -> Result<Self, PostgresKitError>
pub async fn connect( database_url: &str, plan: SchemaPlan, ) -> Result<Self, PostgresKitError>
Connects an operator without mutating the database.
Sourcepub async fn setup(&self) -> Result<SetupOutcome, PostgresKitError>
pub async fn setup(&self) -> Result<SetupOutcome, PostgresKitError>
Creates a missing schema and applies the complete authored plan atomically.
Setup is idempotent for an already-current managed schema, but will not adopt an unmanaged schema or perform an upgrade.
Sourcepub async fn upgrade(&self) -> Result<UpgradeOutcome, PostgresKitError>
pub async fn upgrade(&self) -> Result<UpgradeOutcome, PostgresKitError>
Applies only pending migrations to an existing managed schema atomically.